==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/PRODUCTIONREQUESTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour PRODUCTIONREQUESTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PRODUCTIONREQUESTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONREQUESTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONREQUESTREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="auto_generated" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRODUCTIONREQUESTID_Type", propOrder = {
    "productionrequestcode",
    "productionrequestrevision",
    "organizationid",
    "description"
})
public class PRODUCTIONREQUESTID_Type {

    @XmlElement(name = "PRODUCTIONREQUESTCODE", required = true)
    protected String productionrequestcode;
    @XmlElement(name = "PRODUCTIONREQUESTREVISION", required = true)
    protected QUANTITY productionrequestrevision;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlAttribute(name = "auto_generated")
    protected Boolean auto_Generated;

    /**
     * Obtient la valeur de la propriété productionrequestcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONREQUESTCODE() {
        return productionrequestcode;
    }

    /**
     * Définit la valeur de la propriété productionrequestcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONREQUESTCODE(String value) {
        this.productionrequestcode = value;
    }

    /**
     * Obtient la valeur de la propriété productionrequestrevision.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPRODUCTIONREQUESTREVISION() {
        return productionrequestrevision;
    }

    /**
     * Définit la valeur de la propriété productionrequestrevision.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPRODUCTIONREQUESTREVISION(QUANTITY value) {
        this.productionrequestrevision = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Obtient la valeur de la propriété auto_Generated.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAuto_Generated() {
        if (auto_Generated == null) {
            return true;
        } else {
            return auto_Generated;
        }
    }

    /**
     * Définit la valeur de la propriété auto_Generated.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAuto_Generated(Boolean value) {
        this.auto_Generated = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/PRODUCTIONREQUESTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for PRODUCTIONREQUESTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PRODUCTIONREQUESTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONREQUESTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRODUCTIONREQUESTREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="auto_generated" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRODUCTIONREQUESTID_Type", propOrder = {
    "productionrequestcode",
    "productionrequestrevision",
    "organizationid",
    "description"
})
public class PRODUCTIONREQUESTID_Type {

    @XmlElement(name = "PRODUCTIONREQUESTCODE", required = true)
    protected String productionrequestcode;
    @XmlElement(name = "PRODUCTIONREQUESTREVISION", required = true)
    protected QUANTITY productionrequestrevision;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlAttribute(name = "auto_generated")
    protected Boolean auto_Generated;

    /**
     * Gets the value of the productionrequestcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRODUCTIONREQUESTCODE() {
        return productionrequestcode;
    }

    /**
     * Sets the value of the productionrequestcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRODUCTIONREQUESTCODE(String value) {
        this.productionrequestcode = value;
    }

    /**
     * Gets the value of the productionrequestrevision property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPRODUCTIONREQUESTREVISION() {
        return productionrequestrevision;
    }

    /**
     * Sets the value of the productionrequestrevision property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPRODUCTIONREQUESTREVISION(QUANTITY value) {
        this.productionrequestrevision = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the auto_Generated property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAuto_Generated() {
        if (auto_Generated == null) {
            return true;
        } else {
            return auto_Generated;
        }
    }

    /**
     * Sets the value of the auto_Generated property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAuto_Generated(Boolean value) {
        this.auto_Generated = value;
    }

}
